@@ -4,6 +4,7 @@ from ckanext.comments.model import Comment
 
 _validators = {}
 
+
 def validator(func):
     _validators[f"comments_{func.__name__}"] = func
     return func
@@ -15,7 +16,9 @@ def get_validators():
 
 @validator
 def comment_exists(value, context):
-    comment = context['session'].query(Comment).filter_by(id=value).one_or_none()
+    comment = (
+        context["session"].query(Comment).filter_by(id=value).one_or_none()
+    )
     if not comment:
-        raise tk.Invalid('Comment does not exist')
+        raise tk.Invalid("Comment does not exist")
     return value
